/**
 * This useClassNames use from rsuite
 * see more detail at link below
 * https://github.com/rsuite/rsuite/blob/908e8f43d2cc8a8a3919cf216ae5405be54fd63a/src/utils/useClassNames.ts#L34
 */
import { useCallback } from 'react';
import classNames from 'classnames';
import { addPrefix } from './classPrefix';
/**
 * Add a prefix to all classNames.
 *
 * @param str prefix of className
 * @returns { withClassPrefix, merge, prefix }
 *  - withClassPrefix: A function of combining className and adding a prefix to each className.
 *    At the same time, the default `classPrefix` is the first className.
 *  - merge: A merge className function.
 *  - prefix: Add a prefix to className
 *  - rootPrefix
 */
function useClassNames(str) {
    var classPrefix = 'ts';
    var componentName = addPrefix(classPrefix, str);
    /**
     * @example
     *
     * if str = 'button':
     * prefix('red', { active: true }) => 'rs-button-red rs-button-active'
     */
    var prefix = useCallback(function () {
        var classes = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            classes[_i] = arguments[_i];
        }
        var mergeClasses = classes.length
            ? classNames.apply(void 0, classes).split(' ')
                .map(function (item) { return addPrefix(componentName, item); })
            : [];
        return mergeClasses.filter(function (cls) { return cls; }).join(' ');
    }, [componentName]);
    /**
     * @example
     *
     * if str = 'button':
     * withClassPrefix('red', { active: true }) => 'rs-button rs-button-red rs-button-active'
     */
    var withClassPrefix = useCallback(function () {
        var classes = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            classes[_i] = arguments[_i];
        }
        var mergeClasses = prefix(classes);
        return mergeClasses ? componentName + " " + mergeClasses : componentName;
    }, [componentName, prefix]);
    /**
     * @example
     * rootPrefix('btn') => 'rs-btn'
     * rootPrefix('btn', { active: true }) => 'rs-btn rs-active'
     */
    var rootPrefix = function () {
        var classes = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            classes[_i] = arguments[_i];
        }
        var mergeClasses = classes.length
            ? classNames.apply(void 0, classes).split(' ')
                .map(function (item) { return addPrefix(classPrefix, item); })
            : [];
        return mergeClasses.filter(function (cls) { return cls; }).join(' ');
    };
    return {
        withClassPrefix: withClassPrefix,
        merge: classNames,
        prefix: prefix,
        rootPrefix: rootPrefix
    };
}
export default useClassNames;
